@@ -54,7 +54,8 @@ from .data import SubmitResult, CommandResult
 from .utils import (
     SlurmCommandError, SlurmError,
     _build_flag_kv, _get_or_create_default_logger,
-    _env_with, _parse_job_id, _slurm_wait, _parse_result
+    _env_with, _parse_job_id, _slurm_wait, _parse_result,
+    default_gpu_options
 )
 
 
@@ -68,7 +69,7 @@ class Slurm:
             default_timeout: Optional[float] = None,
             base_env: Optional[Mapping[str, str]] = None,
             enable_logging: Union[bool, Logger] = False,
-            config_file_path: str = 'quickslurm.cfg',
+            gpu_enable: bool = False,
     ):
         """
         Args:
@@ -80,13 +81,13 @@ class Slurm:
                 - True: use the built-in logger (file in CWD, fallback /tmp, plus stderr).
                 - False: use a NullHandler (silent).
                 - logging.Logger object: use the provided logger. Note: this is only a log for the quickslurm module.
-            config_file_path: quick slurm config file. "quickslurm.cfg" by default. (More in README)
-                - this file can contain all of the key value pair 
+            gpu_enable: Enable GPU options for sbatch and srun. The default is False.
         """
         self.sbatch_path = sbatch_path
         self.srun_path = srun_path
         self.default_timeout = default_timeout
         self.base_env = _env_with(base_env)
+        self.with_gpu = gpu_enable
 
         if isinstance(enable_logging, logging.Logger):
             self.logger = enable_logging  # logging.getLogger(f"{enable_logging.name}.quickslurm")
@@ -170,8 +171,19 @@ class Slurm:
             script_args = []
 
         cmd = [self.sbatch_path]
+
+        # if options are porvided then run with them checking for GPU options
         if sbatch_options:
+            if self.with_gpu:
+                # use left side options to merge with default GPU to enable dynamic options
+                sbatch_options |= default_gpu_options()
             cmd += _build_flag_kv(sbatch_options)
+
+        elif self.with_gpu:
+            # if no sbatch options are provided, use default GPU options
+            cmd += _build_flag_kv(default_gpu_options())
+            
+
         cmd.append(str(script_path))
         cmd += [str(a) for a in script_args]
 
@@ -179,7 +191,7 @@ class Slurm:
 
     def submit_inline(
             self,
-            command: Sequence[str],
+            command: Union[Sequence[str], str],
             sbatch_options: Optional[Mapping[str, Union[str, int, float, bool]]] = None,
             shebang: str = "#!/bin/bash -l",
             workdir: Optional[Union[str, Path]] = None,
@@ -203,7 +215,8 @@ class Slurm:
         True, the call blocks until the job reaches a terminal state.
 
         Args:
-            command: The program and its arguments to run (e.g., ["python", "train.py", "--epochs", "5"]).
+            command: The program and its arguments to run (e.g., ["python", "train.py", "--epochs", "5"]). 
+                This can also be a string command that is space delimited.
             sbatch_options: Optional mapping of sbatch options (e.g., {"time": "00:10:00", "partition": "short"}).
                 Boolean values are treated as flags (True -> present, False -> omitted).
             shebang: Script interpreter line to place at the top of the generated script.
@@ -237,7 +250,8 @@ class Slurm:
             print(sub.job_id)
             ```
         """
-
+        if isinstance(command, str):
+            command = command.split(' ')
         cmd_line = " ".join(shlex.quote(str(c)) for c in command)
         parts = [shebang, "set -euo pipefail"]
         if workdir:
@@ -406,7 +420,7 @@ class Slurm:
             raise
 
         if cp.returncode != 0:
-            if check:
+            if check and batch:
                 raise SlurmCommandError(
                     f"Command failed (exit {cp.returncode}): {args}\n{cp.stderr.strip()}",
                     CommandResult(cp.returncode, cp.stdout, cp.stderr, list(map(str, args))),
@@ -431,4 +445,4 @@ class Slurm:
         # if srun return the output directly
         else:
             self.logger.debug(f"[srun] Return code: {cp.returncode}", )
-            return SubmitResult(00000, 'UNKNOWN', cp.returncode, cp.stdout, cp.stderr, list(map(str, args)))
+            return SubmitResult(0, 'COMPLETE' if cp.returncode == 0 else 'FAILED', cp.returncode, cp.stdout, cp.stderr, list(map(str, args)))
